# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class TestDataServiceApiRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'TestDataServiceApi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_PathParamss(self): # RepeatList
		return self.get_body_params().get('PathParams')

	def set_PathParamss(self, PathParams):  # RepeatList
		for depth1 in range(len(PathParams)):
			if PathParams[depth1].get('ParamKey') is not None:
				self.add_body_params('PathParams.' + str(depth1 + 1) + '.ParamKey', PathParams[depth1].get('ParamKey'))
			if PathParams[depth1].get('ParamValue') is not None:
				self.add_body_params('PathParams.' + str(depth1 + 1) + '.ParamValue', PathParams[depth1].get('ParamValue'))
	def get_QueryParams(self): # RepeatList
		return self.get_body_params().get('QueryParam')

	def set_QueryParams(self, QueryParam):  # RepeatList
		for depth1 in range(len(QueryParam)):
			if QueryParam[depth1].get('ParamKey') is not None:
				self.add_body_params('QueryParam.' + str(depth1 + 1) + '.ParamKey', QueryParam[depth1].get('ParamKey'))
			if QueryParam[depth1].get('ParamValue') is not None:
				self.add_body_params('QueryParam.' + str(depth1 + 1) + '.ParamValue', QueryParam[depth1].get('ParamValue'))
	def get_HeadParamss(self): # RepeatList
		return self.get_body_params().get('HeadParams')

	def set_HeadParamss(self, HeadParams):  # RepeatList
		for depth1 in range(len(HeadParams)):
			if HeadParams[depth1].get('ParamKey') is not None:
				self.add_body_params('HeadParams.' + str(depth1 + 1) + '.ParamKey', HeadParams[depth1].get('ParamKey'))
			if HeadParams[depth1].get('ParamValue') is not None:
				self.add_body_params('HeadParams.' + str(depth1 + 1) + '.ParamValue', HeadParams[depth1].get('ParamValue'))
	def get_BodyContent(self): # String
		return self.get_body_params().get('BodyContent')

	def set_BodyContent(self, BodyContent):  # String
		self.add_body_params('BodyContent', BodyContent)
	def get_BodyParamss(self): # RepeatList
		return self.get_body_params().get('BodyParams')

	def set_BodyParamss(self, BodyParams):  # RepeatList
		for depth1 in range(len(BodyParams)):
			if BodyParams[depth1].get('ParamKey') is not None:
				self.add_body_params('BodyParams.' + str(depth1 + 1) + '.ParamKey', BodyParams[depth1].get('ParamKey'))
			if BodyParams[depth1].get('ParamValue') is not None:
				self.add_body_params('BodyParams.' + str(depth1 + 1) + '.ParamValue', BodyParams[depth1].get('ParamValue'))
	def get_ApiId(self): # Long
		return self.get_query_params().get('ApiId')

	def set_ApiId(self, ApiId):  # Long
		self.add_query_param('ApiId', ApiId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class ListPermissionApplyOrdersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ListPermissionApplyOrders')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_StartTime(self): # Long
		return self.get_query_params().get('StartTime')

	def set_StartTime(self, StartTime):  # Long
		self.add_query_param('StartTime', StartTime)
	def get_PageNum(self): # Integer
		return self.get_query_params().get('PageNum')

	def set_PageNum(self, PageNum):  # Integer
		self.add_query_param('PageNum', PageNum)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_TableName(self): # String
		return self.get_query_params().get('TableName')

	def set_TableName(self, TableName):  # String
		self.add_query_param('TableName', TableName)
	def get_QueryType(self): # Integer
		return self.get_query_params().get('QueryType')

	def set_QueryType(self, QueryType):  # Integer
		self.add_query_param('QueryType', QueryType)
	def get_EngineType(self): # String
		return self.get_query_params().get('EngineType')

	def set_EngineType(self, EngineType):  # String
		self.add_query_param('EngineType', EngineType)
	def get_MaxComputeProjectName(self): # String
		return self.get_query_params().get('MaxComputeProjectName')

	def set_MaxComputeProjectName(self, MaxComputeProjectName):  # String
		self.add_query_param('MaxComputeProjectName', MaxComputeProjectName)
	def get_EndTime(self): # Long
		return self.get_query_params().get('EndTime')

	def set_EndTime(self, EndTime):  # Long
		self.add_query_param('EndTime', EndTime)
	def get_FlowStatus(self): # Integer
		return self.get_query_params().get('FlowStatus')

	def set_FlowStatus(self, FlowStatus):  # Integer
		self.add_query_param('FlowStatus', FlowStatus)
	def get_WorkspaceId(self): # Integer
		return self.get_query_params().get('WorkspaceId')

	def set_WorkspaceId(self, WorkspaceId):  # Integer
		self.add_query_param('WorkspaceId', WorkspaceId)
	def get_OrderType(self): # Integer
		return self.get_query_params().get('OrderType')

	def set_OrderType(self, OrderType):  # Integer
		self.add_query_param('OrderType', OrderType)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateFileRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateFile')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_FileType(self): # Integer
		return self.get_body_params().get('FileType')

	def set_FileType(self, FileType):  # Integer
		self.add_body_params('FileType', FileType)
	def get_DependentNodeIdList(self): # String
		return self.get_body_params().get('DependentNodeIdList')

	def set_DependentNodeIdList(self, DependentNodeIdList):  # String
		self.add_body_params('DependentNodeIdList', DependentNodeIdList)
	def get_Content(self): # String
		return self.get_body_params().get('Content')

	def set_Content(self, Content):  # String
		self.add_body_params('Content', Content)
	def get_ProjectIdentifier(self): # String
		return self.get_body_params().get('ProjectIdentifier')

	def set_ProjectIdentifier(self, ProjectIdentifier):  # String
		self.add_body_params('ProjectIdentifier', ProjectIdentifier)
	def get_ResourceGroupId(self): # Long
		return self.get_body_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # Long
		self.add_body_params('ResourceGroupId', ResourceGroupId)
	def get_StartImmediately(self): # Boolean
		return self.get_body_params().get('StartImmediately')

	def set_StartImmediately(self, StartImmediately):  # Boolean
		self.add_body_params('StartImmediately', StartImmediately)
	def get_ProjectId(self): # Long
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_body_params('ProjectId', ProjectId)
	def get_AdvancedSettings(self): # String
		return self.get_body_params().get('AdvancedSettings')

	def set_AdvancedSettings(self, AdvancedSettings):  # String
		self.add_body_params('AdvancedSettings', AdvancedSettings)
	def get_StartEffectDate(self): # Long
		return self.get_body_params().get('StartEffectDate')

	def set_StartEffectDate(self, StartEffectDate):  # Long
		self.add_body_params('StartEffectDate', StartEffectDate)
	def get_CycleType(self): # String
		return self.get_body_params().get('CycleType')

	def set_CycleType(self, CycleType):  # String
		self.add_body_params('CycleType', CycleType)
	def get_Owner(self): # String
		return self.get_body_params().get('Owner')

	def set_Owner(self, Owner):  # String
		self.add_body_params('Owner', Owner)
	def get_AutoRerunIntervalMillis(self): # Integer
		return self.get_body_params().get('AutoRerunIntervalMillis')

	def set_AutoRerunIntervalMillis(self, AutoRerunIntervalMillis):  # Integer
		self.add_body_params('AutoRerunIntervalMillis', AutoRerunIntervalMillis)
	def get_InputList(self): # String
		return self.get_body_params().get('InputList')

	def set_InputList(self, InputList):  # String
		self.add_body_params('InputList', InputList)
	def get_RerunMode(self): # String
		return self.get_body_params().get('RerunMode')

	def set_RerunMode(self, RerunMode):  # String
		self.add_body_params('RerunMode', RerunMode)
	def get_ConnectionName(self): # String
		return self.get_body_params().get('ConnectionName')

	def set_ConnectionName(self, ConnectionName):  # String
		self.add_body_params('ConnectionName', ConnectionName)
	def get_OutputParameters(self): # String
		return self.get_body_params().get('OutputParameters')

	def set_OutputParameters(self, OutputParameters):  # String
		self.add_body_params('OutputParameters', OutputParameters)
	def get_ParaValue(self): # String
		return self.get_body_params().get('ParaValue')

	def set_ParaValue(self, ParaValue):  # String
		self.add_body_params('ParaValue', ParaValue)
	def get_ResourceGroupIdentifier(self): # String
		return self.get_body_params().get('ResourceGroupIdentifier')

	def set_ResourceGroupIdentifier(self, ResourceGroupIdentifier):  # String
		self.add_body_params('ResourceGroupIdentifier', ResourceGroupIdentifier)
	def get_AutoRerunTimes(self): # Integer
		return self.get_body_params().get('AutoRerunTimes')

	def set_AutoRerunTimes(self, AutoRerunTimes):  # Integer
		self.add_body_params('AutoRerunTimes', AutoRerunTimes)
	def get_CronExpress(self): # String
		return self.get_body_params().get('CronExpress')

	def set_CronExpress(self, CronExpress):  # String
		self.add_body_params('CronExpress', CronExpress)
	def get_EndEffectDate(self): # Long
		return self.get_body_params().get('EndEffectDate')

	def set_EndEffectDate(self, EndEffectDate):  # Long
		self.add_body_params('EndEffectDate', EndEffectDate)
	def get_FileName(self): # String
		return self.get_body_params().get('FileName')

	def set_FileName(self, FileName):  # String
		self.add_body_params('FileName', FileName)
	def get_InputParameters(self): # String
		return self.get_body_params().get('InputParameters')

	def set_InputParameters(self, InputParameters):  # String
		self.add_body_params('InputParameters', InputParameters)
	def get_Stop(self): # Boolean
		return self.get_body_params().get('Stop')

	def set_Stop(self, Stop):  # Boolean
		self.add_body_params('Stop', Stop)
	def get_DependentType(self): # String
		return self.get_body_params().get('DependentType')

	def set_DependentType(self, DependentType):  # String
		self.add_body_params('DependentType', DependentType)
	def get_FileFolderPath(self): # String
		return self.get_body_params().get('FileFolderPath')

	def set_FileFolderPath(self, FileFolderPath):  # String
		self.add_body_params('FileFolderPath', FileFolderPath)
	def get_FileDescription(self): # String
		return self.get_body_params().get('FileDescription')

	def set_FileDescription(self, FileDescription):  # String
		self.add_body_params('FileDescription', FileDescription)
	def get_AutoParsing(self): # Boolean
		return self.get_body_params().get('AutoParsing')

	def set_AutoParsing(self, AutoParsing):  # Boolean
		self.add_body_params('AutoParsing', AutoParsing)
	def get_SchedulerType(self): # String
		return self.get_body_params().get('SchedulerType')

	def set_SchedulerType(self, SchedulerType):  # String
		self.add_body_params('SchedulerType', SchedulerType)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateQualityRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateQualityRule')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Trend(self): # String
		return self.get_body_params().get('Trend')

	def set_Trend(self, Trend):  # String
		self.add_body_params('Trend', Trend)
	def get_BlockType(self): # Integer
		return self.get_body_params().get('BlockType')

	def set_BlockType(self, BlockType):  # Integer
		self.add_body_params('BlockType', BlockType)
	def get_PropertyType(self): # String
		return self.get_body_params().get('PropertyType')

	def set_PropertyType(self, PropertyType):  # String
		self.add_body_params('PropertyType', PropertyType)
	def get_EntityId(self): # Long
		return self.get_body_params().get('EntityId')

	def set_EntityId(self, EntityId):  # Long
		self.add_body_params('EntityId', EntityId)
	def get_RuleName(self): # String
		return self.get_body_params().get('RuleName')

	def set_RuleName(self, RuleName):  # String
		self.add_body_params('RuleName', RuleName)
	def get_Checker(self): # Integer
		return self.get_body_params().get('Checker')

	def set_Checker(self, Checker):  # Integer
		self.add_body_params('Checker', Checker)
	def get_Operator(self): # String
		return self.get_body_params().get('Operator')

	def set_Operator(self, Operator):  # String
		self.add_body_params('Operator', Operator)
	def get_Property(self): # String
		return self.get_body_params().get('Property')

	def set_Property(self, Property):  # String
		self.add_body_params('Property', Property)
	def get_Id(self): # Long
		return self.get_body_params().get('Id')

	def set_Id(self, Id):  # Long
		self.add_body_params('Id', Id)
	def get_WarningThreshold(self): # String
		return self.get_body_params().get('WarningThreshold')

	def set_WarningThreshold(self, WarningThreshold):  # String
		self.add_body_params('WarningThreshold', WarningThreshold)
	def get_ProjectId(self): # Long
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_body_params('ProjectId', ProjectId)
	def get_MethodName(self): # String
		return self.get_body_params().get('MethodName')

	def set_MethodName(self, MethodName):  # String
		self.add_body_params('MethodName', MethodName)
	def get_ProjectName(self): # String
		return self.get_body_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_body_params('ProjectName', ProjectName)
	def get_RuleType(self): # Integer
		return self.get_body_params().get('RuleType')

	def set_RuleType(self, RuleType):  # Integer
		self.add_body_params('RuleType', RuleType)
	def get_TemplateId(self): # Integer
		return self.get_body_params().get('TemplateId')

	def set_TemplateId(self, TemplateId):  # Integer
		self.add_body_params('TemplateId', TemplateId)
	def get_ExpectValue(self): # String
		return self.get_body_params().get('ExpectValue')

	def set_ExpectValue(self, ExpectValue):  # String
		self.add_body_params('ExpectValue', ExpectValue)
	def get_WhereCondition(self): # String
		return self.get_body_params().get('WhereCondition')

	def set_WhereCondition(self, WhereCondition):  # String
		self.add_body_params('WhereCondition', WhereCondition)
	def get_CriticalThreshold(self): # String
		return self.get_body_params().get('CriticalThreshold')

	def set_CriticalThreshold(self, CriticalThreshold):  # String
		self.add_body_params('CriticalThreshold', CriticalThreshold)
	def get_OpenSwitch(self): # Boolean
		return self.get_body_params().get('OpenSwitch')

	def set_OpenSwitch(self, OpenSwitch):  # Boolean
		self.add_body_params('OpenSwitch', OpenSwitch)
	def get_Comment(self): # String
		return self.get_body_params().get('Comment')

	def set_Comment(self, Comment):  # String
		self.add_body_params('Comment', Comment)
	def get_PredictType(self): # Integer
		return self.get_body_params().get('PredictType')

	def set_PredictType(self, PredictType):  # Integer
		self.add_body_params('PredictType', PredictType)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateDagComplementRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateDagComplement')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ProjectEnv(self): # String
		return self.get_body_params().get('ProjectEnv')

	def set_ProjectEnv(self, ProjectEnv):  # String
		self.add_body_params('ProjectEnv', ProjectEnv)
	def get_StartBizDate(self): # String
		return self.get_body_params().get('StartBizDate')

	def set_StartBizDate(self, StartBizDate):  # String
		self.add_body_params('StartBizDate', StartBizDate)
	def get_Parallelism(self): # Boolean
		return self.get_body_params().get('Parallelism')

	def set_Parallelism(self, Parallelism):  # Boolean
		self.add_body_params('Parallelism', Parallelism)
	def get_RootNodeId(self): # Long
		return self.get_body_params().get('RootNodeId')

	def set_RootNodeId(self, RootNodeId):  # Long
		self.add_body_params('RootNodeId', RootNodeId)
	def get_BizBeginTime(self): # String
		return self.get_body_params().get('BizBeginTime')

	def set_BizBeginTime(self, BizBeginTime):  # String
		self.add_body_params('BizBeginTime', BizBeginTime)
	def get_EndBizDate(self): # String
		return self.get_body_params().get('EndBizDate')

	def set_EndBizDate(self, EndBizDate):  # String
		self.add_body_params('EndBizDate', EndBizDate)
	def get_IncludeNodeIds(self): # String
		return self.get_body_params().get('IncludeNodeIds')

	def set_IncludeNodeIds(self, IncludeNodeIds):  # String
		self.add_body_params('IncludeNodeIds', IncludeNodeIds)
	def get_BizEndTime(self): # String
		return self.get_body_params().get('BizEndTime')

	def set_BizEndTime(self, BizEndTime):  # String
		self.add_body_params('BizEndTime', BizEndTime)
	def get_Name(self): # String
		return self.get_body_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_body_params('Name', Name)
	def get_ExcludeNodeIds(self): # String
		return self.get_body_params().get('ExcludeNodeIds')

	def set_ExcludeNodeIds(self, ExcludeNodeIds):  # String
		self.add_body_params('ExcludeNodeIds', ExcludeNodeIds)
	def get_NodeParams(self): # String
		return self.get_body_params().get('NodeParams')

	def set_NodeParams(self, NodeParams):  # String
		self.add_body_params('NodeParams', NodeParams)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateUdfFileRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateUdfFile')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ReturnValue(self): # String
		return self.get_body_params().get('ReturnValue')

	def set_ReturnValue(self, ReturnValue):  # String
		self.add_body_params('ReturnValue', ReturnValue)
	def get_Resources(self): # String
		return self.get_body_params().get('Resources')

	def set_Resources(self, Resources):  # String
		self.add_body_params('Resources', Resources)
	def get_FunctionType(self): # String
		return self.get_body_params().get('FunctionType')

	def set_FunctionType(self, FunctionType):  # String
		self.add_body_params('FunctionType', FunctionType)
	def get_CmdDescription(self): # String
		return self.get_body_params().get('CmdDescription')

	def set_CmdDescription(self, CmdDescription):  # String
		self.add_body_params('CmdDescription', CmdDescription)
	def get_UdfDescription(self): # String
		return self.get_body_params().get('UdfDescription')

	def set_UdfDescription(self, UdfDescription):  # String
		self.add_body_params('UdfDescription', UdfDescription)
	def get_ParameterDescription(self): # String
		return self.get_body_params().get('ParameterDescription')

	def set_ParameterDescription(self, ParameterDescription):  # String
		self.add_body_params('ParameterDescription', ParameterDescription)
	def get_ProjectIdentifier(self): # String
		return self.get_body_params().get('ProjectIdentifier')

	def set_ProjectIdentifier(self, ProjectIdentifier):  # String
		self.add_body_params('ProjectIdentifier', ProjectIdentifier)
	def get_Example(self): # String
		return self.get_body_params().get('Example')

	def set_Example(self, Example):  # String
		self.add_body_params('Example', Example)
	def get_ClassName(self): # String
		return self.get_body_params().get('ClassName')

	def set_ClassName(self, ClassName):  # String
		self.add_body_params('ClassName', ClassName)
	def get_FileFolderPath(self): # String
		return self.get_body_params().get('FileFolderPath')

	def set_FileFolderPath(self, FileFolderPath):  # String
		self.add_body_params('FileFolderPath', FileFolderPath)
	def get_ProjectId(self): # Long
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_body_params('ProjectId', ProjectId)
	def get_FileId(self): # String
		return self.get_body_params().get('FileId')

	def set_FileId(self, FileId):  # String
		self.add_body_params('FileId', FileId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateDataServiceApiRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateDataServiceApi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ScriptDetails(self): # String
		return self.get_body_params().get('ScriptDetails')

	def set_ScriptDetails(self, ScriptDetails):  # String
		self.add_body_params('ScriptDetails', ScriptDetails)
	def get_RequestMethod(self): # Integer
		return self.get_body_params().get('RequestMethod')

	def set_RequestMethod(self, RequestMethod):  # Integer
		self.add_body_params('RequestMethod', RequestMethod)
	def get_ApiDescription(self): # String
		return self.get_body_params().get('ApiDescription')

	def set_ApiDescription(self, ApiDescription):  # String
		self.add_body_params('ApiDescription', ApiDescription)
	def get_Timeout(self): # Integer
		return self.get_body_params().get('Timeout')

	def set_Timeout(self, Timeout):  # Integer
		self.add_body_params('Timeout', Timeout)
	def get_ResourceGroupId(self): # Long
		return self.get_body_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # Long
		self.add_body_params('ResourceGroupId', ResourceGroupId)
	def get_TenantId(self): # Long
		return self.get_body_params().get('TenantId')

	def set_TenantId(self, TenantId):  # Long
		self.add_body_params('TenantId', TenantId)
	def get_Protocols(self): # String
		return self.get_body_params().get('Protocols')

	def set_Protocols(self, Protocols):  # String
		self.add_body_params('Protocols', Protocols)
	def get_ProjectId(self): # Long
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_body_params('ProjectId', ProjectId)
	def get_ResponseContentType(self): # Integer
		return self.get_body_params().get('ResponseContentType')

	def set_ResponseContentType(self, ResponseContentType):  # Integer
		self.add_body_params('ResponseContentType', ResponseContentType)
	def get_ApiPath(self): # String
		return self.get_body_params().get('ApiPath')

	def set_ApiPath(self, ApiPath):  # String
		self.add_body_params('ApiPath', ApiPath)
	def get_WizardDetails(self): # String
		return self.get_body_params().get('WizardDetails')

	def set_WizardDetails(self, WizardDetails):  # String
		self.add_body_params('WizardDetails', WizardDetails)
	def get_VisibleRange(self): # Integer
		return self.get_body_params().get('VisibleRange')

	def set_VisibleRange(self, VisibleRange):  # Integer
		self.add_body_params('VisibleRange', VisibleRange)
	def get_RegistrationDetails(self): # String
		return self.get_body_params().get('RegistrationDetails')

	def set_RegistrationDetails(self, RegistrationDetails):  # String
		self.add_body_params('RegistrationDetails', RegistrationDetails)
	def get_ApiId(self): # Long
		return self.get_body_params().get('ApiId')

	def set_ApiId(self, ApiId):  # Long
		self.add_body_params('ApiId', ApiId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateTableRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateTable')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Schema(self): # String
		return self.get_query_params().get('Schema')

	def set_Schema(self, Schema):  # String
		self.add_query_param('Schema', Schema)
	def get_ClientToken(self): # String
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self, ClientToken):  # String
		self.add_query_param('ClientToken', ClientToken)
	def get_Columnss(self): # RepeatList
		return self.get_body_params().get('Columns')

	def set_Columnss(self, Columns):  # RepeatList
		for depth1 in range(len(Columns)):
			if Columns[depth1].get('SeqNumber') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.SeqNumber', Columns[depth1].get('SeqNumber'))
			if Columns[depth1].get('IsPartitionCol') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.IsPartitionCol', Columns[depth1].get('IsPartitionCol'))
			if Columns[depth1].get('ColumnNameCn') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.ColumnNameCn', Columns[depth1].get('ColumnNameCn'))
			if Columns[depth1].get('Length') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.Length', Columns[depth1].get('Length'))
			if Columns[depth1].get('Comment') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.Comment', Columns[depth1].get('Comment'))
			if Columns[depth1].get('ColumnName') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.ColumnName', Columns[depth1].get('ColumnName'))
			if Columns[depth1].get('ColumnType') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.ColumnType', Columns[depth1].get('ColumnType'))
	def get_LifeCycle(self): # Integer
		return self.get_query_params().get('LifeCycle')

	def set_LifeCycle(self, LifeCycle):  # Integer
		self.add_query_param('LifeCycle', LifeCycle)
	def get_Themess(self): # RepeatList
		return self.get_body_params().get('Themes')

	def set_Themess(self, Themes):  # RepeatList
		for depth1 in range(len(Themes)):
			if Themes[depth1].get('ThemeLevel') is not None:
				self.add_body_params('Themes.' + str(depth1 + 1) + '.ThemeLevel', Themes[depth1].get('ThemeLevel'))
			if Themes[depth1].get('ThemeId') is not None:
				self.add_body_params('Themes.' + str(depth1 + 1) + '.ThemeId', Themes[depth1].get('ThemeId'))
	def get_LogicalLevelId(self): # Long
		return self.get_query_params().get('LogicalLevelId')

	def set_LogicalLevelId(self, LogicalLevelId):  # Long
		self.add_query_param('LogicalLevelId', LogicalLevelId)
	def get_Endpoint(self): # String
		return self.get_body_params().get('Endpoint')

	def set_Endpoint(self, Endpoint):  # String
		self.add_body_params('Endpoint', Endpoint)
	def get_EnvType(self): # Integer
		return self.get_body_params().get('EnvType')

	def set_EnvType(self, EnvType):  # Integer
		self.add_body_params('EnvType', EnvType)
	def get_HasPart(self): # Integer
		return self.get_query_params().get('HasPart')

	def set_HasPart(self, HasPart):  # Integer
		self.add_query_param('HasPart', HasPart)
	def get_TableName(self): # String
		return self.get_query_params().get('TableName')

	def set_TableName(self, TableName):  # String
		self.add_query_param('TableName', TableName)
	def get_AppGuid(self): # String
		return self.get_query_params().get('AppGuid')

	def set_AppGuid(self, AppGuid):  # String
		self.add_query_param('AppGuid', AppGuid)
	def get_ProjectId(self): # Long
		return self.get_query_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_query_param('ProjectId', ProjectId)
	def get_CategoryId(self): # Long
		return self.get_query_params().get('CategoryId')

	def set_CategoryId(self, CategoryId):  # Long
		self.add_query_param('CategoryId', CategoryId)
	def get_Visibility(self): # Integer
		return self.get_query_params().get('Visibility')

	def set_Visibility(self, Visibility):  # Integer
		self.add_query_param('Visibility', Visibility)
	def get_PhysicsLevelId(self): # Long
		return self.get_query_params().get('PhysicsLevelId')

	def set_PhysicsLevelId(self, PhysicsLevelId):  # Long
		self.add_query_param('PhysicsLevelId', PhysicsLevelId)
	def get_OwnerId(self): # String
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # String
		self.add_query_param('OwnerId', OwnerId)
	def get_IsView(self): # Integer
		return self.get_query_params().get('IsView')

	def set_IsView(self, IsView):  # Integer
		self.add_query_param('IsView', IsView)
	def get_ExternalTableType(self): # String
		return self.get_query_params().get('ExternalTableType')

	def set_ExternalTableType(self, ExternalTableType):  # String
		self.add_query_param('ExternalTableType', ExternalTableType)
	def get_Location(self): # String
		return self.get_query_params().get('Location')

	def set_Location(self, Location):  # String
		self.add_query_param('Location', Location)
	def get_Comment(self): # String
		return self.get_query_params().get('Comment')

	def set_Comment(self, Comment):  # String
		self.add_query_param('Comment', Comment)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class GetMetaColumnLineageRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetMetaColumnLineage')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_DataSourceType(self): # String
		return self.get_query_params().get('DataSourceType')

	def set_DataSourceType(self, DataSourceType):  # String
		self.add_query_param('DataSourceType', DataSourceType)
	def get_ClusterId(self): # String
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self, ClusterId):  # String
		self.add_query_param('ClusterId', ClusterId)
	def get_PageNum(self): # Integer
		return self.get_query_params().get('PageNum')

	def set_PageNum(self, PageNum):  # Integer
		self.add_query_param('PageNum', PageNum)
	def get_ColumnName(self): # String
		return self.get_query_params().get('ColumnName')

	def set_ColumnName(self, ColumnName):  # String
		self.add_query_param('ColumnName', ColumnName)
	def get_ColumnGuid(self): # String
		return self.get_query_params().get('ColumnGuid')

	def set_ColumnGuid(self, ColumnGuid):  # String
		self.add_query_param('ColumnGuid', ColumnGuid)
	def get_DatabaseName(self): # String
		return self.get_query_params().get('DatabaseName')

	def set_DatabaseName(self, DatabaseName):  # String
		self.add_query_param('DatabaseName', DatabaseName)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_TableName(self): # String
		return self.get_query_params().get('TableName')

	def set_TableName(self, TableName):  # String
		self.add_query_param('TableName', TableName)
	def get_Direction(self): # String
		return self.get_query_params().get('Direction')

	def set_Direction(self, Direction):  # String
		self.add_query_param('Direction', Direction)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateMetaTableRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateMetaTable')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Schema(self): # String
		return self.get_query_params().get('Schema')

	def set_Schema(self, Schema):  # String
		self.add_query_param('Schema', Schema)
	def get_Visibility(self): # Integer
		return self.get_query_params().get('Visibility')

	def set_Visibility(self, Visibility):  # Integer
		self.add_query_param('Visibility', Visibility)
	def get_Caption(self): # String
		return self.get_query_params().get('Caption')

	def set_Caption(self, Caption):  # String
		self.add_query_param('Caption', Caption)
	def get_NewOwnerId(self): # String
		return self.get_query_params().get('NewOwnerId')

	def set_NewOwnerId(self, NewOwnerId):  # String
		self.add_query_param('NewOwnerId', NewOwnerId)
	def get_TableGuid(self): # String
		return self.get_query_params().get('TableGuid')

	def set_TableGuid(self, TableGuid):  # String
		self.add_query_param('TableGuid', TableGuid)
	def get_AddedLabels(self): # String
		return self.get_body_params().get('AddedLabels')

	def set_AddedLabels(self, AddedLabels):  # String
		self.add_body_params('AddedLabels', AddedLabels)
	def get_RemovedLabels(self): # String
		return self.get_body_params().get('RemovedLabels')

	def set_RemovedLabels(self, RemovedLabels):  # String
		self.add_body_params('RemovedLabels', RemovedLabels)
	def get_EnvType(self): # Integer
		return self.get_query_params().get('EnvType')

	def set_EnvType(self, EnvType):  # Integer
		self.add_query_param('EnvType', EnvType)
	def get_TableName(self): # String
		return self.get_query_params().get('TableName')

	def set_TableName(self, TableName):  # String
		self.add_query_param('TableName', TableName)
	def get_ProjectId(self): # Long
		return self.get_query_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_query_param('ProjectId', ProjectId)
	def get_CategoryId(self): # Long
		return self.get_query_params().get('CategoryId')

	def set_CategoryId(self, CategoryId):  # Long
		self.add_query_param('CategoryId', CategoryId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class RevokeColumnPermissionRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'RevokeColumnPermission')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_RevokeUserName(self): # String
		return self.get_query_params().get('RevokeUserName')

	def set_RevokeUserName(self, RevokeUserName):  # String
		self.add_query_param('RevokeUserName', RevokeUserName)
	def get_MaxComputeProjectName(self): # String
		return self.get_query_params().get('MaxComputeProjectName')

	def set_MaxComputeProjectName(self, MaxComputeProjectName):  # String
		self.add_query_param('MaxComputeProjectName', MaxComputeProjectName)
	def get_Columns(self): # String
		return self.get_query_params().get('Columns')

	def set_Columns(self, Columns):  # String
		self.add_query_param('Columns', Columns)
	def get_RevokeUserId(self): # String
		return self.get_query_params().get('RevokeUserId')

	def set_RevokeUserId(self, RevokeUserId):  # String
		self.add_query_param('RevokeUserId', RevokeUserId)
	def get_TableName(self): # String
		return self.get_query_params().get('TableName')

	def set_TableName(self, TableName):  # String
		self.add_query_param('TableName', TableName)
	def get_WorkspaceId(self): # Long
		return self.get_query_params().get('WorkspaceId')

	def set_WorkspaceId(self, WorkspaceId):  # Long
		self.add_query_param('WorkspaceId', WorkspaceId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class ListMetaCollectionsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ListMetaCollections')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Creator(self): # String
		return self.get_query_params().get('Creator')

	def set_Creator(self, Creator):  # String
		self.add_query_param('Creator', Creator)
	def get_Follower(self): # String
		return self.get_query_params().get('Follower')

	def set_Follower(self, Follower):  # String
		self.add_query_param('Follower', Follower)
	def get_ParentQualifiedName(self): # String
		return self.get_query_params().get('ParentQualifiedName')

	def set_ParentQualifiedName(self, ParentQualifiedName):  # String
		self.add_query_param('ParentQualifiedName', ParentQualifiedName)
	def get_OrderBy(self): # String
		return self.get_query_params().get('OrderBy')

	def set_OrderBy(self, OrderBy):  # String
		self.add_query_param('OrderBy', OrderBy)
	def get_CollectionType(self): # String
		return self.get_query_params().get('CollectionType')

	def set_CollectionType(self, CollectionType):  # String
		self.add_query_param('CollectionType', CollectionType)
	def get_Administrator(self): # String
		return self.get_query_params().get('Administrator')

	def set_Administrator(self, Administrator):  # String
		self.add_query_param('Administrator', Administrator)
	def get_NextToken(self): # String
		return self.get_query_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_query_param('NextToken', NextToken)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_Keyword(self): # String
		return self.get_query_params().get('Keyword')

	def set_Keyword(self, Keyword):  # String
		self.add_query_param('Keyword', Keyword)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class ListTopicsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ListTopics')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Owner(self): # String
		return self.get_body_params().get('Owner')

	def set_Owner(self, Owner):  # String
		self.add_body_params('Owner', Owner)
	def get_EndTime(self): # String
		return self.get_body_params().get('EndTime')

	def set_EndTime(self, EndTime):  # String
		self.add_body_params('EndTime', EndTime)
	def get_BeginTime(self): # String
		return self.get_body_params().get('BeginTime')

	def set_BeginTime(self, BeginTime):  # String
		self.add_body_params('BeginTime', BeginTime)
	def get_TopicStatuses(self): # String
		return self.get_body_params().get('TopicStatuses')

	def set_TopicStatuses(self, TopicStatuses):  # String
		self.add_body_params('TopicStatuses', TopicStatuses)
	def get_PageNumber(self): # Integer
		return self.get_body_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_body_params('PageNumber', PageNumber)
	def get_InstanceId(self): # Long
		return self.get_body_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # Long
		self.add_body_params('InstanceId', InstanceId)
	def get_PageSize(self): # Integer
		return self.get_body_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_body_params('PageSize', PageSize)
	def get_TopicTypes(self): # String
		return self.get_body_params().get('TopicTypes')

	def set_TopicTypes(self, TopicTypes):  # String
		self.add_body_params('TopicTypes', TopicTypes)
	def get_NodeId(self): # Long
		return self.get_body_params().get('NodeId')

	def set_NodeId(self, NodeId):  # Long
		self.add_body_params('NodeId', NodeId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateRemindRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateRemind')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_AlertUnit(self): # String
		return self.get_body_params().get('AlertUnit')

	def set_AlertUnit(self, AlertUnit):  # String
		self.add_body_params('AlertUnit', AlertUnit)
	def get_UseFlag(self): # Boolean
		return self.get_body_params().get('UseFlag')

	def set_UseFlag(self, UseFlag):  # Boolean
		self.add_body_params('UseFlag', UseFlag)
	def get_RobotUrls(self): # String
		return self.get_body_params().get('RobotUrls')

	def set_RobotUrls(self, RobotUrls):  # String
		self.add_body_params('RobotUrls', RobotUrls)
	def get_BizProcessIds(self): # String
		return self.get_body_params().get('BizProcessIds')

	def set_BizProcessIds(self, BizProcessIds):  # String
		self.add_body_params('BizProcessIds', BizProcessIds)
	def get_RemindType(self): # String
		return self.get_body_params().get('RemindType')

	def set_RemindType(self, RemindType):  # String
		self.add_body_params('RemindType', RemindType)
	def get_BaselineIds(self): # String
		return self.get_body_params().get('BaselineIds')

	def set_BaselineIds(self, BaselineIds):  # String
		self.add_body_params('BaselineIds', BaselineIds)
	def get_ProjectId(self): # Long
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_body_params('ProjectId', ProjectId)
	def get_DndEnd(self): # String
		return self.get_body_params().get('DndEnd')

	def set_DndEnd(self, DndEnd):  # String
		self.add_body_params('DndEnd', DndEnd)
	def get_RemindUnit(self): # String
		return self.get_body_params().get('RemindUnit')

	def set_RemindUnit(self, RemindUnit):  # String
		self.add_body_params('RemindUnit', RemindUnit)
	def get_AlertInterval(self): # Integer
		return self.get_body_params().get('AlertInterval')

	def set_AlertInterval(self, AlertInterval):  # Integer
		self.add_body_params('AlertInterval', AlertInterval)
	def get_AlertMethods(self): # String
		return self.get_body_params().get('AlertMethods')

	def set_AlertMethods(self, AlertMethods):  # String
		self.add_body_params('AlertMethods', AlertMethods)
	def get_MaxAlertTimes(self): # Integer
		return self.get_body_params().get('MaxAlertTimes')

	def set_MaxAlertTimes(self, MaxAlertTimes):  # Integer
		self.add_body_params('MaxAlertTimes', MaxAlertTimes)
	def get_AlertTargets(self): # String
		return self.get_body_params().get('AlertTargets')

	def set_AlertTargets(self, AlertTargets):  # String
		self.add_body_params('AlertTargets', AlertTargets)
	def get_Webhooks(self): # String
		return self.get_body_params().get('Webhooks')

	def set_Webhooks(self, Webhooks):  # String
		self.add_body_params('Webhooks', Webhooks)
	def get_RemindId(self): # Long
		return self.get_body_params().get('RemindId')

	def set_RemindId(self, RemindId):  # Long
		self.add_body_params('RemindId', RemindId)
	def get_Detail(self): # String
		return self.get_body_params().get('Detail')

	def set_Detail(self, Detail):  # String
		self.add_body_params('Detail', Detail)
	def get_RemindName(self): # String
		return self.get_body_params().get('RemindName')

	def set_RemindName(self, RemindName):  # String
		self.add_body_params('RemindName', RemindName)
	def get_NodeIds(self): # String
		return self.get_body_params().get('NodeIds')

	def set_NodeIds(self, NodeIds):  # String
		self.add_body_params('NodeIds', NodeIds)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreatePermissionApplyOrderRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreatePermissionApplyOrder')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ApplyReason(self): # String
		return self.get_query_params().get('ApplyReason')

	def set_ApplyReason(self, ApplyReason):  # String
		self.add_query_param('ApplyReason', ApplyReason)
	def get_MaxComputeProjectName(self): # String
		return self.get_query_params().get('MaxComputeProjectName')

	def set_MaxComputeProjectName(self, MaxComputeProjectName):  # String
		self.add_query_param('MaxComputeProjectName', MaxComputeProjectName)
	def get_ApplyObjects(self): # RepeatList
		return self.get_query_params().get('ApplyObject')

	def set_ApplyObjects(self, ApplyObject):  # RepeatList
		for depth1 in range(len(ApplyObject)):
			if ApplyObject[depth1].get('ColumnMetaList') is not None:
				for depth2 in range(len(ApplyObject[depth1].get('ColumnMetaList'))):
					if ApplyObject[depth1].get('ColumnMetaList')[depth2].get('Name') is not None:
						self.add_query_param('ApplyObject.' + str(depth1 + 1) + '.ColumnMetaList.'  + str(depth2 + 1) + '.Name', ApplyObject[depth1].get('ColumnMetaList')[depth2].get('Name'))
			if ApplyObject[depth1].get('Name') is not None:
				self.add_query_param('ApplyObject.' + str(depth1 + 1) + '.Name', ApplyObject[depth1].get('Name'))
			if ApplyObject[depth1].get('Actions') is not None:
				self.add_query_param('ApplyObject.' + str(depth1 + 1) + '.Actions', ApplyObject[depth1].get('Actions'))
	def get_ApplyUserIds(self): # String
		return self.get_query_params().get('ApplyUserIds')

	def set_ApplyUserIds(self, ApplyUserIds):  # String
		self.add_query_param('ApplyUserIds', ApplyUserIds)
	def get_Deadline(self): # Long
		return self.get_query_params().get('Deadline')

	def set_Deadline(self, Deadline):  # Long
		self.add_query_param('Deadline', Deadline)
	def get_WorkspaceId(self): # Integer
		return self.get_query_params().get('WorkspaceId')

	def set_WorkspaceId(self, WorkspaceId):  # Integer
		self.add_query_param('WorkspaceId', WorkspaceId)
	def get_OrderType(self): # Integer
		return self.get_query_params().get('OrderType')

	def set_OrderType(self, OrderType):  # Integer
		self.add_query_param('OrderType', OrderType)
	def get_EngineType(self): # String
		return self.get_query_params().get('EngineType')

	def set_EngineType(self, EngineType):  # String
		self.add_query_param('EngineType', EngineType)
